.. image:: images/help.png
    :align: left

========================
Help pages for Telemeta
========================

For technical assistance, please join our mailing list:
    
    `http://lists.parisson.com/cgi-bin/mailman/listinfo/telemeta <http://lists.parisson.com/cgi-bin/mailman/listinfo/telemeta>`_
    
or contact the hotline by email:
        
     support@parisson.com
        
or twitter:
            
    `http://twitter.com/telemeta <http://twitter.com/telemeta>`_
            
For more informations about the Telemeta system, see `telemeta.org <http://telemeta.org>`_
            
Telemeta uses the audio librairy TimeSide : `code.google.com/p/timeside/ <http://code.google.com/p/timeside/>`_